@@ -9,7 +9,11 @@ module Webgen::ContentProcessor
     def initialize(doc, context) #:nodoc:
       super(doc)
       @context = context
-      @do_convert = context.website.config['contentprocessor.kramdown.handle_links']
+      @do_convert = if context.options.has_key?('contentprocessor.kramdown.handle_links')
+                      context.options['contentprocessor.kramdown.handle_links']
+                    else
+                      context.website.config['contentprocessor.kramdown.handle_links']
+                    end
     end
 
     # Convert the Kramdown document +doc+ to HTML using the webgen +context+ object.
@@ -19,12 +23,12 @@ module Webgen::ContentProcessor
 
     def convert_a(el, indent, opts)
       el.options[:attr]['href'] = @context.tag('relocatable', {'path' => el.options[:attr]['href']}) if @do_convert
-      "<a#{options_for_element(el)}>#{inner(el, indent, opts)}</a>"
+      "<a#{html_attributes(el)}>#{inner(el, indent, opts)}</a>"
     end
 
     def convert_img(el, indent, opts)
       el.options[:attr]['src'] = @context.tag('relocatable', {'path' => el.options[:attr]['src']}) if @do_convert
-      "<img#{options_for_element(el)} />"
+      "<img#{html_attributes(el)} />"
     end
 
   end
