@@ -16,7 +16,7 @@ class TestContentProcessorSass < Test::Unit::TestCase
     context = Webgen::Context.new(:content => "#main\n  :background-color #000",
                                                     :chain => [node])
     obj.call(context)
-    assert_equal("#main {\n  background-color: #000; }\n", context.content)
+    assert_equal("#main {\n  background-color: black; }\n", context.content)
 
     context.content = "#cont\n = 5"
     assert_error_on_line(Webgen::RenderError, 2) { obj.call(context) }
